==> haskell-storablevector-0.2.13.2-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storablevector
version:              0.2.13.2
visibility:           public
id:                   storablevector-0.2.13.2-2kwr9JzpMzSI0f18SBKOe8
key:                  storablevector-0.2.13.2-2kwr9JzpMzSI0f18SBKOe8
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  71cbb3f0653e25414a47d63c8da9fad1
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storablevector
hs-libraries:         HSstorablevector-0.2.13.2-2kwr9JzpMzSI0f18SBKOe8
depends:
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP base-4.17.2.1
    deepseq-1.4.8.0 non-negative-0.1.2-BYXN92A4ltjDc2yUQ6sa5R
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb transformers-0.5.6.2
    unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    utility-ht-0.0.17.2-KaqmtwuVjoaG2EV9Ezq1Sq

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13.2-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storablevector
version:              0.2.13.2
visibility:           public
id:                   storablevector-0.2.13.2-LMQ6TTWsJOpJg4puINW2Oa
key:                  storablevector-0.2.13.2-LMQ6TTWsJOpJg4puINW2Oa
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  5eba5827886e1f8ad9e7c8ee1ba8c127
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storablevector-0.2.13.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storablevector
hs-libraries:         HSstorablevector-0.2.13.2-LMQ6TTWsJOpJg4puINW2Oa
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF base-4.17.2.1
    deepseq-1.4.8.0 non-negative-0.1.2-LwUOsN6MAXC3zv3iX7QcOc
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb transformers-0.5.6.2
    unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    utility-ht-0.0.17.2-71byj5QpPjWBQJOAqtvJWi

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
